/*
 * HFS (aka MAC) filesystem/handler for MorphOS/AmigaOS
 * Author: Marek 'March' Szyprowski <marek@amiga.pl>
 */

#ifndef __MACFS_HANDLER_H
#define __MACFS_HANDLER_H

#include "libhfs/hfs.h"

/* filesystem structures */

#define ID_HFS_DISK 0x4D414300lu

#define ACTION_VOLUME_ADD 16000
#define ACTION_VOLUME_REMOVE 16001
#define ACTION_DOSENVEC_UPDATE 16002
#define ACTION_DOSNODE_KILL 16003

#define ACTION_SET_MAC_BOOTABLE 17000

#define DEF_POOL_SIZE 65536
#define DEF_POOL_TRESHOLD DEF_POOL_SIZE

/* MAC Type & Creator values for new files */

#define RAW_TYPE   "????"
#define RAW_CREA   "UNIX"

struct ExtFileLock
{
	/* struct FileLock */
	BPTR            fl_Link;
	ULONG  			fl_Key;
	LONG            fl_Access;
	struct MsgPort *fl_Task;
	BPTR            fl_Volume;

	/* coinsistency check */
	ULONG 			magic;
	struct FSSuper	*sb;
	ULONG			parid;
	hfsdir			*dir;
	hfsfile			*file;
	ULONG			lastcid;
	ULONG			lastpos;
};

struct FSSuper {
	struct FSSuper *next;
	struct DosList *doslist;

	BOOL disk_invalid;
	BOOL read_only;
	ULONG lock_key;

	UBYTE name[32];	/* BCPL zero terminated string */

	ULONG blocksize;	/* HFS block size */
	ULONG total_blocks;
	ULONG free_blocks;
	ULONG create_date;

	hfsvol *vol;  /* libhfs mess */
};


struct Globals {
	/* libs */
	struct ExecBase *SysBase;
	struct DosLibrary *DOSBase;
	struct Library *UtilityBase;
	struct Library *IntuitionBase;

	/* mem/task */
    struct Task *ourtask;
    struct MsgPort *ourport;
	APTR mempool;

	/* fs */
	struct DosList *devnode;
	struct FileSysStartupMsg *fssm;
	struct MsgPort *notifyport;
	LONG quit;
	BOOL autodetect;

	/* io */
	struct IOExtTD *diskioreq;
	struct IOExtTD *diskchgreq;
	APTR diskchgintdata;
	struct MsgPort *diskport;
	LONG buffers_count;

	/* volumes */
	struct FSSuper *sb;    /* current sb */
	struct FSSuper *sblist;   /* list of sbs with outstanding locks */

	/* disk status */
    LONG disk_inserted;
	LONG disk_inhibited;
};

register struct Globals *glob __asm("r13");

#if 0
#undef SysBase
#undef DOSBase
#undef UtilityBase
#undef IntuitionBase

#define SysBase glob->SysBase
#define DOSBase glob->DOSBase
#define UtilityBase glob->UtilityBase
#define IntuitionBase glob->IntuitionBase

#endif

#include "support.h"

#endif
